import os
import pandas as pd
import geopandas as gpd
from shapely.geometry import shape
from concurrent.futures import ThreadPoolExecutor

# Define the list of locations you're interested in
interested_locations = ['Austria', 'Belgium', 'Bulgaria', 'Croatia', 'Cyprus', 'CzechRepublic', 'Denmark', 'Estonia', 'Finland', 'France', 'Germany', 'Greece', 'Hungary', 'Ireland', 'Italy', 'Latvia', 'Lithuania', 'Luxembourg', 'Malta', 'Netherlands', 'Poland', 'Portugal', 'Romania', 'Slovakia', 'Slovenia', 'Spain', 'Sweden', 'Iceland', 'Switzerland', 'Liechtenstein', 'Norway', 'UnitedKingdom', 'Ukraine', 'UnitedStates']

def process_file(row):
    file_path = f"data/{row['QuadKey']}.geojson"
    if row['Location'] in interested_locations and not os.path.exists(file_path):
        df = pd.read_json(row['Url'], lines=True)
        df['geometry'] = df['geometry'].apply(shape)
        gdf = gpd.GeoDataFrame(df, crs=4326)
        gdf.to_file(file_path, driver="GeoJSON")

def main():
    dataset_links = pd.read_csv("https://minedbuildings.blob.core.windows.net/global-buildings/dataset-links.csv")

    if not os.path.exists('data'):
        os.makedirs('data')

    # Use ThreadPoolExecutor to process files in parallel
    with ThreadPoolExecutor(max_workers=20) as executor:
        executor.map(process_file, dataset_links.to_dict(orient='records'))

if __name__ == "__main__":
    main()
